@@ -5,7 +5,7 @@ from .utils import str_to_var_name, format_pattern, order_flag_options, order_fl
 from .flag_bits import FlagBits8, FlagBits16, FlagBits32, FlagBits64, FLAG_BITS_SELECTOR
 
 
-__all__ = ['BitFlags', 'bitflags']
+__all__ = ['BitFlagsMetaclass', 'BitFlags', 'bitflags']
 
 
 class BitFlagsMetaclass(type(ctypes.Union)):
@@ -82,7 +82,7 @@ class BitFlagsMetaclass(type(ctypes.Union)):
                 pass
 
         # Format the pattern argument into options and fields.
-        if 'pattern' in attrs:
+        if 'pattern' in attrs and attrs['pattern']:
             pattern = attrs['pattern']
             for i in range(nbytes*8):
                 if i not in options:
@@ -204,9 +204,17 @@ class BitFlags(ctypes.Union, metaclass=BitFlagsMetaclass):
         """Set the bit flags.
 
         Args:
-            value (int/str/list/tuple): Integer value or list of string options to set.
+            value (bytes/int/str/list/tuple): Bytes value, integer value, or list of string options to set.
         """
-        if isinstance(value, int):
+        if isinstance(value, bytes):
+            byteorder = getattr(self, 'byteorder', None)
+            if byteorder is None:
+                byteorder = getattr(self, 'endian', 'big')
+            signed = getattr(self, 'signed', False)
+            self.value = int.from_bytes(value, byteorder=byteorder, signed=signed)
+            return
+
+        elif isinstance(value, int):
             self.value = value
             return
 
@@ -299,6 +307,9 @@ class BitFlags(ctypes.Union, metaclass=BitFlagsMetaclass):
     def __int__(self):
         return self.value
 
+    def __repr__(self):
+        return '{}({})'.format(self.__class__.__name__, self.get_flags())
+
     def __str__(self):
         return ', '.join(self.get_flags())
 
